/*
 * ImageCalibration
 *
 * Copyright (C) 2006 Guilhem Bonnefille <guilhem.bonnefille@gmail.com>
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#import "CalibratingImageModel.h"

#import "CalibratingPointModel.h"

@implementation CalibratingImageModel

- (id) init
{
  int i;

  self = [super init];
  image = nil;
  for (i = 0 ; i < MAX_POINTS ; i++) {
    points[i] = [[CalibratingPointModel alloc] init];
  }
  return self;
}

- (void) dealloc
{
  [image release];
  [super dealloc];
}

- (NSImage *) image
{
  return image;
}

- (void) setImage: (NSImage *) theImage
{
  [theImage retain];
  [image release];
  image = theImage;
}

- (void) setPoint: (CalibratingPointModel*) thePoint At: (int) pos
{
  if (pos >= 0 && pos < MAX_POINTS) {
    [thePoint retain];
    [points[pos] release];
    points[pos] = thePoint;
  }
}

- (CalibratingPointModel*) getPointAt: (int) pos
{
  if (pos >= 0 && pos < MAX_POINTS)
    return points[pos];
  else
    return nil;
}

@end


