/*
 * ImageCalibration
 *
 * Copyright (C) 2006 Guilhem Bonnefille <guilhem.bonnefille@gmail.com>
 * Inspired by Gautier Taravella on Sun Jun 20 2004 (FlightTrack).
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#import "CalibratingPointView.h"

#include <math.h>

#define CROSS_SIZE 5

@interface CalibratingPointView (InternalMethods)
- (void) setColor;
- (void) makeCross:(NSPoint)loc;
- (void) makeNumber:(NSPoint)loc;
@end

@implementation CalibratingPointView

- (id) init
{
  [super init];

  [self resetPoint];

  return self;
}

- (id) initWithNumber: (int) newNumber
{
  NSLog(@"initWithNumber:%d\n",
         newNumber);
  number = newNumber;

  [super init];

  [self resetPoint];

  return self;
}

- (id) initWithPoint: (NSPoint) newPoint andNumber: (int) newNumber
{
  NSLog(@"initWithPoint:%fx%f andNumber:%d\n",
         newPoint.x, newPoint.y, newNumber);
  NSRect frame;

  [self setPoint:newPoint];
  number = newNumber;

  [super init];

  return self;
}

- (void) resetPoint
{
  point.x = -1;
  point.x = -1;
}

- (BOOL) setPoint: (NSPoint) newPoint
{
  NSLog(@"[CalibratingPointView%d]setPoint:%fx%f\n",
         number, newPoint.x, newPoint.y);
  BOOL needDisplay = NO;
  if (point.x != newPoint.x && point.y != newPoint.y)
    {
      point = newPoint;

      needDisplay = YES;
    }

  return needDisplay;
}

- (NSPoint) getPoint
{
  return point;
}

- (void) setNumber: (int) newNumber
{
  if (number != newNumber) {
      number = newNumber;
    }
}

- (void)draw:(NSPoint)loc inRect:(NSRect)rect
{
  NSLog(@"drawRect{%f,%f,%f,%f}\n",
         rect.origin.x,rect.origin.x,rect.size.width,rect.size.height);

  if (point.x != -1) {
    [self makeCross:loc];
    [self makeNumber:loc];
  }
}

- (void) setColor
{
  if (selected)
    [[NSColor yellowColor] set];
  else
    [[NSColor redColor] set];
}

- (void) makeCross:(NSPoint)loc {

    NSBezierPath * cross = [NSBezierPath bezierPath];
    NSPoint p = loc;
    p.x -= CROSS_SIZE;
    [cross moveToPoint: p];
    p.x += 2*CROSS_SIZE;
    [cross lineToPoint: p];
    p = loc;
    p.y -= CROSS_SIZE;
    [cross moveToPoint: p];
    p.y += 2*CROSS_SIZE;
    [cross lineToPoint: p];
 
    [self setColor];
    [cross stroke];

    // Save the bounds
    crossBounds = [cross bounds];
}

- (void) makeNumber:(NSPoint)loc {
    
  [self setColor];

    NSRect rect = NSMakeRect (loc.x + 3, loc.y + 3,
                              15, 15);    
    [[NSBezierPath bezierPathWithOvalInRect: rect] fill];
    
    NSString * string = [NSString stringWithFormat:@"%d", number];
    NSDictionary * attr = [NSDictionary dictionaryWithObjectsAndKeys:
        [NSFont labelFontOfSize:10], NSFontAttributeName,
        [NSColor whiteColor], NSForegroundColorAttributeName,
        nil];
    NSSize ss = [string sizeWithAttributes:attr];
    [string drawAtPoint:NSMakePoint (rect.origin.x + rect.size.width/2 - ss.width/2,
                                     rect.origin.y + rect.size.height/2 - ss.height/2)
         withAttributes: attr];

    // Save the bounds
    numberBounds = rect;
}

- (BOOL) selectAt: (NSPoint) loc
{
  NSSize size;

  NSLog(@"CalibratingPointView::selectAt: %@",
        NSStringFromPoint(loc));

  NSLog(@"CalibratingPointView::selectAt: numberBounds %@ crossBounds %@",
        NSStringFromRect(numberBounds), NSStringFromRect(crossBounds));

  size.width = loc.x - numberBounds.origin.x;
  size.height = loc.y - numberBounds.origin.y;
  if (0 <= size.width && size.width <= numberBounds.size.width &&
      0 <= size.height && size.height <= numberBounds.size.height)
    return YES;

  size.width = loc.x - crossBounds.origin.x;
  size.height = loc.y - crossBounds.origin.y;
  if (0 <= size.width && size.width <= crossBounds.size.width &&
      0 <= size.height && size.height <= crossBounds.size.height)
    return YES;

  return NO;
}

- (void) select
{
  selected = YES;
}

- (void) unselect
{
  selected = NO;
}

@end
