/*
 * ImageCalibration
 *
 * Copyright (C) 2006 Guilhem Bonnefille <guilhem.bonnefille@gmail.com>
 * Inspired by Gautier Taravella on Sun Jun 20 2004 (FlightTrack).
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#import "GTGeoCoordinatesFormatter.h"

@implementation GTGeoCoordinatesFormatter

- (id) initWithType: (int) formatType {
    self = [super init];
    if (self) {
        isLatitudeFormatter = (formatType == GTPositionLatitudeFormat);
    }
    return self;
}

- (NSString *)stringForObjectValue:(id)anObject {
    // Object is a NSNumber
    return [NSString stringWithFormat:@"%f", [anObject doubleValue]];
}

- (NSString *)editingStringForObjectValue:(id)anObject {
    // Object is a NSNumber
    return [NSString stringWithFormat:@"%f", [anObject doubleValue]];
}

- (NSAttributedString *)attributedStringForObjectValue:(id)anObject withDefaultAttributes:(NSDictionary *)attributes {
    NSAttributedString * attStr = [[NSAttributedString alloc] initWithString:[self stringForObjectValue:anObject]
                                                                  attributes:attributes];
    [attStr autorelease];
    return attStr;
}

- (BOOL)getObjectValue:(id *)anObject forString:(NSString *)entry errorDescription:(NSString **)error {
    int errorCode = 0;
    double value = [entry doubleValue];
    
    if (errorCode) {
        return NO;
        NSLog(@"Entry error %d", errorCode);
    } else {
        *anObject = [NSNumber numberWithDouble: value];
        return YES;
    }
}


/*
- (BOOL)isPartialStringValid:(NSString **)partialStringPtr proposedSelectedRange:(NSRangePointer)proposedSelRangePtr originalString:(NSString *)origString originalSelectedRange:(NSRange)origSelRange errorDescription:(NSString **)error {
    id foo;
    BOOL ok = [self getObjectValue:&foo forString:*partialStringPtr errorDescription:nil];
    NSLog(@"%d Initial: %@ At: %d l:%d Original:%@  At: %d l:%d", ok, *partialStringPtr, proposedSelRangePtr->location, proposedSelRangePtr->length, origString, origSelRange.location, origSelRange.length);
}
*/

- (void)setLatitudeFormatter: (BOOL)yesOrNo {
    isLatitudeFormatter = yesOrNo;
}

- (BOOL)isLatitudeFormatter {
    return isLatitudeFormatter;
}

// Class methods

static GTGeoCoordinatesFormatter * applicationLatitudeFormatter = nil;
static GTGeoCoordinatesFormatter * applicationLongitudeFormatter = nil;


+ (GTGeoCoordinatesFormatter *) applicationLatitudeFormatter {
  // TODO: make it thread safe
  if (applicationLatitudeFormatter == nil)
    applicationLatitudeFormatter =
      [[GTGeoCoordinatesFormatter alloc] initWithType:GTPositionLatitudeFormat];
  return applicationLatitudeFormatter;
}

+ (GTGeoCoordinatesFormatter *) applicationLongitudeFormatter {
  // TODO: make it thread safe
  if (applicationLongitudeFormatter == nil)
    applicationLongitudeFormatter =
      [[GTGeoCoordinatesFormatter alloc] initWithType: GTPositionLongitudeFormat];
  return applicationLongitudeFormatter;
}

@end
