/*
 * ImageCalibration
 *
 * Copyright (C) 2006 Guilhem Bonnefille <guilhem.bonnefille@gmail.com>
 * Inspired by Gautier Taravella on Sun Jun 20 2004 (FlightTrack).
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#import <AppKit/AppKit.h>

/** Proper size for the view as of current design (in order to take into account
* some extra pixels if UTM entry is possible) is 217x19 pixels.
*/
@interface GTGeoCoordinatesView : NSView {
    IBOutlet id delegate;
    id latTF;
    id lonTF;
    id utmTF;
    NSMenu * formatMenu;
    id formatB;
    int mode;
    
    BOOL editable;
    BOOL bezeled;
    
    double latitude;
    double longitude;
}

/** This method is called by the coponents of the view upon user action. */
- (void) valueChanged: (id) sender;

/** Sets the delegate of the view. The delegate of the view will receive a
* positionChanged:(id)view message when the value of the position represented in the
* view has been modified by the user.
*/
- (void) setDelegate: (id) aDelegate;

- (void) setLatitude: (double) latitude;
- (void) setLongitude: (double) longitude;
- (double) latitude;
- (double) longitude;

- (void)setEditable:(BOOL)flag;
- (BOOL)isEditable;
- (void)setBezeled:(BOOL)flag;
- (BOOL)isBezeled;

/** Called by the notification center to notify that the default format has changed and that the
* display should be refreshed.
*/
- (void) formatChanged:(NSNotification *) notification;


@end
