/*
 * ImageCalibration
 *
 * Copyright (C) 2006 Guilhem Bonnefille <guilhem.bonnefille@gmail.com>
 * Inspired by Gautier Taravella on Sun Jun 20 2004 (FlightTrack).
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#import "GTGeoCoordinatesView.h"

#import "GTGeoCoordinatesFormatter.h"
#import "Foundation/Foundation.h"

@interface GTGeoCoordinatesView (InternalMethods)

@end

@implementation GTGeoCoordinatesView

- (id)initWithFrame:(NSRect)frame {
    //NSLog(@"%@ initwithFrame", self);
    self = [super initWithFrame:frame];
    if (self) {
        // Initialization code here.
        NSFont * font = [NSFont systemFontOfSize:[NSFont smallSystemFontSize]];
        
        latTF = [[NSTextField alloc] initWithFrame:NSMakeRect(0, 0, 91, 19)];
        [latTF setFormatter: [GTGeoCoordinatesFormatter applicationLatitudeFormatter]];
        [[latTF cell] setSendsActionOnEndEditing:YES];
        [self addSubview:latTF];
        [[latTF cell] setFont: font];
        [latTF setTarget: self];
        [latTF setAction: @selector(valueChanged:)];
        lonTF = [[NSTextField alloc] initWithFrame:NSMakeRect(99, 0, 96, 19)];
        [lonTF setFormatter: [GTGeoCoordinatesFormatter applicationLongitudeFormatter]];
        [[lonTF cell] setSendsActionOnEndEditing:YES];
        [self addSubview:lonTF];
        [[lonTF cell] setFont: font];
        [lonTF setTarget: self];
        [lonTF setAction: @selector(valueChanged:)];
        
        [self setEditable: YES];
        
        formatMenu = [[NSMenu alloc] init];
        
        
        [[NSNotificationCenter defaultCenter] addObserver: self selector:@selector(formatChanged:) name:@"COORDINATES_FORMAT" object:nil];
    }
    return self;
}

- (void)drawRect:(NSRect)rect {
    [super drawRect:rect];
}


- (void) setLatitude: (double) pLatitude {
    self->latitude = pLatitude;
    [latTF setObjectValue: [NSNumber numberWithDouble: latitude]];
}

- (void) setLongitude: (double) pLongitude {
    self->longitude = pLongitude;
    [lonTF setObjectValue: [NSNumber numberWithDouble: longitude]];
}

- (double) latitude {
    return latitude;
}

- (double) longitude {
    return longitude;
}

- (void) setDelegate: (id) aDelegate {
    if (delegate != aDelegate) {
        [delegate release];
        delegate = [aDelegate retain];
    }
}

- (void) formatChanged:(NSNotification *) notification {
    [lonTF setNeedsDisplay:YES];
    [latTF setNeedsDisplay:YES];
}


- (void) valueChanged: (id) sender {
    // Update internal state
    latitude = [[latTF objectValue] doubleValue];
    longitude = [[lonTF objectValue] doubleValue];
    
    //NSLog(@"Value changed on %@: (%f,%f)", self, latitude, longitude);

    // Warn delegate
    if (delegate != nil &&  [delegate respondsToSelector:@selector(positionChanged:)]) {
        [delegate positionChanged: self];
    }
    
}

- (void)setBezeled:(BOOL)flag {
    bezeled = flag;
    
    [lonTF setBezeled: flag];
    [latTF setBezeled: flag];
    [[lonTF cell] setDrawsBackground:flag];
    [[latTF cell] setDrawsBackground:flag];
}

- (BOOL)isBezeled {
    return bezeled;
}

- (void)setEditable:(BOOL)flag {
    editable = flag;
 
    [lonTF setEditable: flag];
    [latTF setEditable: flag]; 
}


- (BOOL)isEditable {
    return editable;
}

@end
