//
//  ImageCalibrationController.h
//  FlightTrack
//
//  Created by Gautier Taravella on Sun Jun 20 2004.
//  Copyright (c) 2004 __MyCompanyName__. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "CalibratingImageView.h"
#import "ImagePositionListener.h"
#import "GTGeoCoordinatesView.h"
#include "gdal.h"

#define NOTIFICATION_IMAGE_CALIBRATED @"ImageCalibrated"

#define MAX_CALIBRATION_POINTS 3

class OGRSpatialReference;
class OGRCoordinateTransformation;


@interface ImageCalibrationController : NSObject <ImagePositionListener> {
    IBOutlet NSWindow * window;
    IBOutlet NSScrollView * scrollView;
    IBOutlet CalibratingImageView * view;
    IBOutlet id zoomInB;
    IBOutlet id zoomOutB;
    IBOutlet id actualSizeB;
    IBOutlet id zoomToFitB;
    IBOutlet id addMapB;
    IBOutlet id cursorXTF;
    IBOutlet id cursorYTF;
    IBOutlet GTGeoCoordinatesView * cursorGeoTF;
    IBOutlet id datumPopup;
    IBOutlet id projTabView;
    IBOutlet id projPopup;
    IBOutlet id projParamMx;
    IBOutlet id projUTMHemiMx;
    IBOutlet id projUTMZoneTF;
    
    
    // Calibration with 2 or 3 points
    GTGeoCoordinatesView * geoPts[MAX_CALIBRATION_POINTS];  // Views for the 2 or 3 points method (contains the next 3 objects)
    IBOutlet GTGeoCoordinatesView * latLon1V;
    IBOutlet GTGeoCoordinatesView * latLon2V;
    IBOutlet GTGeoCoordinatesView * latLon3V;
    IBOutlet id pointMx;
    
    // Calibration with affine transform parameters
    IBOutlet id affineTransformMx;
    IBOutlet id affineTransformUnitsMx;
    IBOutlet id selMethodMx;
    IBOutlet NSImageView * geoRefComputeImageV;
    
    IBOutlet NSImageView * projStatusImageV;
    IBOutlet NSImageView * geoRefStatusImageV; 

    // Internal state for geo-reference
    GDAL_GCP gcps [MAX_CALIBRATION_POINTS];  // World coordinates are assumed to be lat/lon in the selected datum
    int geoRefMethod;
    double geoTransform[6]; // Contains the affine transform coefficents that are used (modified everytime an update is made
                            // so that they are always coherent (or NaN).
    BOOL isGeoreferenced;
    
    // Temporary variables
    GDAL_GCP gcpsForComputation [MAX_CALIBRATION_POINTS];
    
    // Projection & Datum information
    OGRSpatialReference ** paGeoCS; // All the supported DATUMs
    OGRSpatialReference * srs;
    OGRCoordinateTransformation * reverseTrans, *forwardTrans;
    NSString * ogrProjName;
    NSDictionary * projParamStrings;
 
    NSString * fileName;
    //NSPoint point1, point2, point3;
    //BOOL point1OK, point2OK, point3OK;
    //double lat1, lon1, lat2, lon2, lat3, lon3;

    int trackingRect;
    
}

- (void) setFileToCalibrate: (NSString *)fileName;
- (NSString *) fileToCalibrate;

- (IBAction) geoRefAction: (id) sender;
- (IBAction) projAction: (id) sender;
- (IBAction) action: (id) sender;
- (void) mouseMovedOnImage: (NSPoint) point;
- (void) mouseDownOnImage: (NSPoint) point;

@end
